@@ -8,7 +8,7 @@
 ##' @return initial estimates of the parameters
 ##' @references 
 ##' \enumerate{
-##'     \item Benjamin M. Taylor. Auxiliary Variable Markov Chain Monte Carlo for Spatial Survival and Geostatistical Models. Benjamin M. Taylor. Submitted. http://arxiv.org/abs/1501.01665
+##'     \item Benjamin M. Taylor. Auxiliary Variable Markov Chain Monte Carlo for Spatial Survival and Geostatistical Models. Benjamin M. Taylor. Submitted. \url{http://arxiv.org/abs/1501.01665}
 ##' }
 ##' @export
 
@@ -81,13 +81,27 @@ maxlikparamPHsurv <- function(surv,X,control){
 ##' @return ...
 ##' @references 
 ##' \enumerate{
-##'     \item Benjamin M. Taylor. Auxiliary Variable Markov Chain Monte Carlo for Spatial Survival and Geostatistical Models. Benjamin M. Taylor. Submitted. http://arxiv.org/abs/1501.01665
+##'     \item Benjamin M. Taylor. Auxiliary Variable Markov Chain Monte Carlo for Spatial Survival and Geostatistical Models. Benjamin M. Taylor. Submitted. \url{http://arxiv.org/abs/1501.01665}
 ##' }
 ##' @export
 
 NonSpatialLogLikelihood_or_gradient <- function(surv,X,beta,omega,control,loglikelihood,gradient){
+
+    censoringtype <- control$censoringtype
+    censored <- control$censored
+    notcensored <- control$notcensored
+    Ctest <- control$Ctest
+    Utest <- control$Utest
+    rightcensored <- control$rightcensored
+    notcensored <- control$notcensored
+    leftcensored <- control$leftcensored
+    intervalcensored <- control$intervalcensored
+    Rtest <- control$Rtest
+    Utest <- control$Utest
+    Ltest <- control$Ltest
+    Itest <- control$Itest
     
-    censoringtype <- attr(surv,"type")
+    # censoringtype <- attr(surv,"type")
     
     omegaorig <- omega # recall we are working with omega on the transformed scale
     omega <- control$omegaitrans(omega) # this is omega on the correct scale
@@ -99,25 +113,25 @@ NonSpatialLogLikelihood_or_gradient <- function(surv,X,beta,omega,control,loglik
     Xbeta <- X%*%beta
     expXbeta <- exp(Xbeta)
     
-    if(censoringtype=="left" | censoringtype=="right"){
-        censored <- surv[,"status"]==0
-        notcensored <- !censored
+    # if(censoringtype=="left" | censoringtype=="right"){
+    #     censored <- surv[,"status"]==0
+    #     notcensored <- !censored
 
-        Ctest <- any(censored)
-        Utest <- any(notcensored)        
+    #     Ctest <- any(censored)
+    #     Utest <- any(notcensored)        
         
-    }
-    else{
-        rightcensored <- surv[,"status"] == 0
-        notcensored <- surv[,"status"] == 1
-        leftcensored <- surv[,"status"] == 2
-        intervalcensored <- surv[,"status"] == 3
+    # }
+    # else{
+    #     rightcensored <- surv[,"status"] == 0
+    #     notcensored <- surv[,"status"] == 1
+    #     leftcensored <- surv[,"status"] == 2
+    #     intervalcensored <- surv[,"status"] == 3
 
-        Rtest <- any(rightcensored)        
-        Utest <- any(notcensored) 
-        Ltest <- any(leftcensored)
-        Itest <- any(intervalcensored)
-    }
+    #     Rtest <- any(rightcensored)        
+    #     Utest <- any(notcensored) 
+    #     Ltest <- any(leftcensored)
+    #     Itest <- any(intervalcensored)
+    # }
 
     
 
