@@ -1,41 +1,43 @@
 ##' simsurv function
 ##'
-##' A function to simulate spatial parametric proportional hazards model with baseline hazard derived from the exponential or weibull model. The function works
+##' A function to simulate spatial parametric proportional hazards model. The function works
 ##' by simulating candidate survival times using MCMC in parallel for each individual based on each individual's covariates and the common
 ##' parameter effects, beta.  
 ##'
 ##' @param X a matrix of covariate information 
 ##' @param beta the parameter effects 
-##' @param theta parameter for the baseline hazard model (the rate for exponential data and the shape and scale for Weibull data)
+##' @param omega vector of parameters for the baseline hazard model
 ##' @param dist the distribution choice: exp or weibull at present
 ##' @param coords matrix with 2 columns giving the coordinates at which to simulate data
 ##' @param cov.parameters a vector: the parameters for the covariance function
 ##' @param cov.model an object of class covmodel, see ?covmodel
 ##' @param mcmc.control mcmc control paramters, see ?mcmcpars
 ##' @param savechains save all chains? runs faster if set to FALSE, but then you'll be unable to conduct convergence/mixing diagnostics
-##' @return simulated survival times from the exponential model (the last simulated value from the MCMC chains)
-##' @seealso \link{covmodel}, \link{survspat} 
+##' @return in list element 'survtimes', a vector of simulated survival times (the last simulated value from the MCMC chains) 
+##' in list element 'T' the MCMC chains
+##' @seealso \link{covmodel}, \link{survspat}, \link{tpowHaz}, \link{exponentialHaz}, \link{gompertzHaz}, \link{makehamHaz}, \link{weibullHaz} 
 ##' @export
 
 simsurv <- function(X=cbind(age=runif(100,5,50),sex=rbinom(100,1,0.5),cancer=rbinom(100,1,0.2)),
-                            beta=matrix(c(0.0296,0.0261,0.035),3,1),
-                            theta=1,
+                            beta=c(0.0296,0.0261,0.035),
+                            omega=1,
                             dist="exp",
                             coords=matrix(runif(2*nrow(X)),nrow(X),2),
                             cov.parameters=c(1,0.1),
                             cov.model=covmodel(model="exponential",pars=NULL),
                             mcmc.control=mcmcpars(nits=100000,burn=10000,thin=90),      
-                            savechains=TRUE){
+                            savechains=TRUE){                         
+
+    beta <- matrix(beta,length(beta),1)
 
     mcmcloop <- mcmcLoop(N=mcmc.control$nits,burnin=mcmc.control$burn,thin=mcmc.control$thin,progressor=mcmcProgressTextBar)
-    
+
     distmat <- as.matrix(dist(coords))
 
     n <- nrow(X)
     u <- as.vector(distmat)
 
-    transpars <- sapply(1:length(cov.parameters),function(i){cov.model$trans[[i]](cov.parameters[i])})
-    sigma <- matrix(EvalCov(cov.model,u=u,parameters=transpars),n,n) # note that the parameters are back transformed in the call to EvalCov  
+    sigma <- matrix(EvalCov(cov.model,u=u,parameters=cov.parameters),n,n)  
     
     sigmachol <- t(chol(sigma))
     Y <- -cov.parameters[which(cov.model$parnames=="sigma")]^2/2 + sigmachol%*%rnorm(n)
@@ -43,7 +45,9 @@ simsurv <- function(X=cbind(age=runif(100,5,50),sex=rbinom(100,1,0.5),cancer=rbi
  
     XbetaplusY <- X%*%beta + Y
     expXbetaplusY <- exp(XbetaplusY)
-    #rexpXbeta <- rate*expXbeta
+    
+    h <- basehazard(dist)(omega)    
+    H <- cumbasehazard(dist)(omega)
     
     nmatrows <- ceiling((mcmc.control$nits-mcmc.control$burn-mcmcloop$waste)/mcmc.control$thin)
     
@@ -57,14 +61,17 @@ simsurv <- function(X=cbind(age=runif(100,5,50),sex=rbinom(100,1,0.5),cancer=rbi
     acrec <- rep(NA,nmatrows)
     count <- 1 # counter to index retained iteration numbers
     
-    if(dist=="exp"){
-        t <- rexp(n,theta)
-    }
-    else if(dist=="weibull"){
-        t <- rweibull(n,shape=theta[1],scale=theta[2])
-    }
+    #if(dist=="exp"){
+    #    t <- rexp(n,omega)
+    #}
+    #else if(dist=="weibull"){
+    #    transpars <- transformweibull(omega)
+    #    t <- rweibull(n,shape=transpars[1],scale=transpars[2])
+    #}
     
-    oldltar <- do.call(paste(dist,"_ltar",sep=""),list(t=t,XbetaplusY=XbetaplusY,expXbetaplusY=expXbetaplusY,theta=theta))
+    t <- rep(1,n)
+    
+    oldltar <- XbetaplusY + log(h(t)) - expXbetaplusY*H(t) 
     
     tbar <- rep(0,n)
     nsamp <- 0
@@ -72,7 +79,7 @@ simsurv <- function(X=cbind(age=runif(100,5,50),sex=rbinom(100,1,0.5),cancer=rbi
     while(nextStep(mcmcloop)){        
     
         newt <- rexp(n,rate=1/t) 
-        newltar <- do.call(paste(dist,"_ltar",sep=""),list(t=newt,XbetaplusY=XbetaplusY,expXbetaplusY=expXbetaplusY,theta=theta))
+        newltar <- XbetaplusY + log(h(newt)) - expXbetaplusY*H(newt)
         
         frac <- exp(newltar-oldltar+dexp(t,1/newt,log=TRUE)-dexp(newt,1/t,log=TRUE))        
         
@@ -109,5 +116,5 @@ simsurv <- function(X=cbind(age=runif(100,5,50),sex=rbinom(100,1,0.5),cancer=rbi
     
     cat("Mean acceptance:",mean(acrec),"\n")
     
-    return(list(X=X,T=T,survtimes=tchoice,theta=theta,beta=beta,tarrec=tarrec,n=n,Y=Y,dist=dist,coords=coords,cov.parameters=cov.parameters,distmat=distmat,u=u))
+    return(list(X=X,T=T,survtimes=tchoice,omega=omega,beta=beta,tarrec=tarrec,n=n,Y=Y,dist=dist,coords=coords,cov.parameters=cov.parameters,distmat=distmat,u=u))
 }
\ No newline at end of file
